contexttools.ContextMark
========================

.. abjad-lineage:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark

.. autoclass:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.attach
      ~abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.detach
      ~abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.effective_context
      ~abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.start_component
      ~abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.storage_format
      ~abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.target_context
      ~abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__call__
      ~abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__copy__
      ~abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__eq__
      ~abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__ne__
      ~abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__repr__

Bases
-----

- :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.effective_context
   :noindex:

.. autoattribute:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.start_component
   :noindex:

.. autoattribute:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.storage_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.target_context
   :noindex:

Methods
-------

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.attach
   :noindex:

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.detach
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__call__
   :noindex:

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__copy__
   :noindex:

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__eq__
   :noindex:

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__ne__
   :noindex:

.. automethod:: abjad.tools.contexttools.ContextMark.ContextMark.ContextMark.__repr__
   :noindex:
